@@ -16,6 +16,7 @@ from .kmer_lookup import Advanced2
 from .parser import OneLineFastaParser, Sequences
 from shared_memory_wrapper import from_shared_memory, to_shared_memory, SingleSharedArray
 from shared_memory_wrapper.shared_memory import remove_shared_memory_in_session
+from shared_memory_wrapper.shared_memory import get_shared_pool
 from pathos.multiprocessing import Pool
 from itertools import repeat
 
@@ -37,6 +38,8 @@ def map_fasta_command(args):
         sys.exit(1)
 
 
+    get_shared_pool(args.n_threads)
+
     if args.kmer_index is None:
         if args.index_bundle is None:
             logging.error("Either a kmer index (-i) or an index bundle (-b) needs to be specified")
@@ -53,6 +56,11 @@ def map_fasta_command(args):
                 cls = MinimalKmerIndex
             kmer_index = cls.from_file(args.kmer_index)
 
+    kmer_index._ref_offsets = np.array([0])
+    kmer_index._hashes_to_index = kmer_index._hashes_to_index.astype(np.int32)
+    kmer_index._nodes = kmer_index._nodes.astype(np.int32)
+    kmer_index._n_kmers = kmer_index._n_kmers.astype(np.int32)
+    kmer_index._modulo = np.uint64(kmer_index._modulo)
     map_fasta(args, kmer_index)
 
 
